#
#-------------------------------------------------------------------------------
# @(#) common-modules/Example/UserConfig.pm common-modules_r3.3.0.4:cset.001773:5:5 08/16/05 @(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# My Vendor Interface
#
# Copyright (c) 2005 Vallent Software Systems UK. All rights reserved.
#
package UserConfig;

# Company Name: 

@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

#use diagnostics;
use strict;
use Exporter ();

#-------------------------------------------------------------------------------


# The following counters are inserted into CELLGPRS blocks
my %insert_cellgprs_constants = 
(
"RLC_User_Blocksize_CS2" => "234",
"RLC_User_Rate_CS2" => "12000",
"RLC_Raw_Blocksize_CS2" => "265",
"RLC_Raw_Blocksize_MC9" => "584",
"RLC_User_BlockSize_MC19" => "552",
);

# The following counters are inserted into CELTCH block
my %insert_celtch_constants =
(
"Cell_1080189681_rpd" => "24",
);

my $ss_seven_hslpg_cntr = 0;

my @rules = (

#----------------------------------------------------------------------------
# Modify/Add rules here
#----------------------------------------------------------------------------
#{
#    'RULE_TYPE'              => 'MY_POSTPARSER_TOOL',
#    'RULE_DESC'              => 'My Postparser tool',
#    'INPUT_FILE_DESCRIPTION' => ['TRARTMET.*-#-I.pif'],
#    'PRODUCE_PIF'            => 'True',
#    'PRODUCE_LIF'            => 'True',
#},
#
#
#
#

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Insert CELLGPRS constants",
    'INPUT_FILE_DESCRIPTION' => ["CELLGPRS-#-.*-#-I.pif"],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'HEADER_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        # create a new counter
        my $key="";
        foreach $key (keys(%insert_cellgprs_constants))
        {
            $c_ref->{$key}=$insert_cellgprs_constants{$key};
        }
        # keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'AC',
},

{
    'RULE_TYPE' => 'JOIN',
    'RULE_NAME' => 'Join CELLGPRS, CELLGPRS2, CELLGPRS3, CELLGPRS4, CELLGPRSO',
    'INPUT_FILE_DESCRIPTION' => [ "CELLGPRS-#(.*)-#-\\d+-#-I-#-AC.pif",
    "CELLGPRS2-#(.*)-#-\\d+-#-I.pif",
    "CELLGPRS3-#(.*)-#-\\d+-#-I.pif",
    "CELLGPRS4-#(.*)-#-\\d+-#-I.pif",
    "CELLGPRSO-#(.*)-#-\\d+-#-I.pif"],
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",
    'OUTPUT_BLOCK_NAME' => "CELLGPRS",
    'COUNTERS_TO_JOIN_ON' => ['OBJ_ID'],
    'OUTPUT_FILENAME_START' => "CELLGPRS",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ["NODEID", "START_DATE", "START_TIME"],
    'NON_APPLICABLE_HEADER_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'REDUNDANT_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Appending External",
    'INPUT_FILE_DESCRIPTION' => ["NECELHO-#-.*-#-I.pif","NECELLREL-#-.*-#-I.pif" ],
    #'INPUT_FILE_DESCRIPTION' => ["NECELLREL-#-.*-#-I.pif" ],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        # create a new counter
        my $key_string = "";
        foreach (keys %$c_ref)
        {
            $key_string= $_;
            if ( ($key_string ne "suspectFlag" ) &&
                    ($key_string ne "OBJ_ID") )
            {
                my $value_string = $c_ref->{$key_string};
                delete $c_ref->{$key_string};
                $c_ref->{$key_string."_External"} = $value_string;
            }
            #else
            #{
            #my $value_string = $c_ref->{$key_string};
            #print "NECELLREL OBJ_ID= $value_string\n";
            #}
        }
        # keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'AX',
},
{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Rename HOVERCNTUTRAN and HOVERSUCUTRAN counters in NUCELLREL",
    'INPUT_FILE_DESCRIPTION' => ["NUCELLREL-#-.*-#-I.pif"],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        # create a new counter
        my $key_string = "";
        my $key_value  = "";
        foreach (keys %$c_ref)
        {
            $key_string= $_;
            if ( $key_string eq "HOVERCNTUTRAN" )
            {
                $key_value  = $c_ref->{$key_string};
                $key_string = "HOVERCNT";
                $c_ref->{$key_string} = $key_value;
                delete $c_ref->{HOVERCNTUTRAN};
            }
            if ( $key_string eq "HOVERSUCUTRAN" )
            {
                $key_value  = $c_ref->{$key_string};
                $key_string = "HOVERSUC";
                $c_ref->{$key_string} = $key_value;
                delete $c_ref->{HOVERSUCUTRAN};
            }

        }
        ## keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'RN',

},

{
    'RULE_TYPE' => 'JOIN',
    'RULE_NAME' => 'Join NCELLREL, NECELLREL, NUCELLREL',
    'INPUT_FILE_DESCRIPTION' => [ "NCELLREL-#(.*)-#-\\d+-#-I.pif","NECELLREL-#(.*)-#-\\d+-#-I.pif","NUCELLREL-#(.*)-#-\\d+-#-I-#-RN.pif"],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "NEIGHBOURHO",
    'COUNTERS_TO_JOIN_ON' => ['OBJ_ID'],
    'OUTPUT_FILENAME_START' => "NEIGHBOURHO",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ["NODEID", "START_DATE", "START_TIME"],
    'NON_APPLICABLE_HEADER_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'REDUNDANT_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Split OBJ_ID into OBJ_ID_1 and OBJ_ID_2",
    'INPUT_FILE_DESCRIPTION' => [
    "NEIGHBOURHO-#-.*-#-J.pif",
    "NCELLREL-#-.*-#-I.pif",
    "NUCELLREL-#-.*-#-I.pif",
    "NECELLREL-#-.*-#-I-#-AX.pif",
    "NECELLREL-#-.*-#-I.pif",
    "NICELHO-#-.*-#-I.pif",
    "NECELHO-#-.*-#-I-#-AX.pif",
    "NECELHO-#-.*-#-I.pif",
    "NECELHOEX-#-.*-#-I.pif",
    "NICELHOEX-#-.*-#-I.pif",
    "NECELASS-#-.*-#-I.pif",
    "NICELASS-#-.*-#-I.pif" ],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        # create a new counter
        my $key_string = "";
        foreach (keys %$c_ref)
        {
            $key_string= $_;
            if ( $key_string eq "OBJ_ID" )
            {
                my $value_string = $c_ref->{$key_string};
                my(@obj_ids)=split(/\-/,$value_string);
                $c_ref->{'OBJ_ID_1'}=$obj_ids[0];
                $c_ref->{'OBJ_ID_2'}=$obj_ids[1];
                last;
            }
        }
        # keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'SO',

},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Split OBJ_ID into LS_ID and SIO_ID for C7LSSI",
    'INPUT_FILE_DESCRIPTION' => [
    "C7LSSI-#-.*-#-I.pif",],
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",
    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        # create a new counter
        my $key_string = "";
        foreach (keys %$c_ref)
        {
            $key_string= $_;
            if ( $key_string eq "OBJ_ID" )
            {
                my $value_string = $c_ref->{$key_string};
                my(@obj_ids)=split(/\-/,$value_string);
                $c_ref->{'LS_ID'}="$obj_ids[0]-$obj_ids[1]";
                $c_ref->{'SIO_ID'}=$obj_ids[2];
                last;
            }
        }
        # keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'SO',

},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Split OBJ_ID into SPC_ID and SIO_ID for C7OPCSIO, C7DPCSIO",
    'INPUT_FILE_DESCRIPTION' => [
    "C7OPCSIO-#-.*-#-I.pif",
    "C7DPCSIO-#-.*-#-I.pif",],
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",
    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        # create a new counter
        my $key_string = "";
        foreach (keys %$c_ref)
        {
            $key_string= $_;
            if ( $key_string eq "OBJ_ID" )
            {
                my $value_string = $c_ref->{$key_string};
                my(@obj_ids)=split(/\-/,$value_string);
                $c_ref->{'SPC_ID'}="$obj_ids[0]-$obj_ids[1]";
                $c_ref->{'SIO_ID'}=$obj_ids[2];
                last;
            }
        }
        # keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'SO',

},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Split OBJ_ID into OPC_ID, DPC_ID and SIO_ID for C7OPCDS and C7ODS",
    'INPUT_FILE_DESCRIPTION' => [
    "C7OPCDS-#-.*-#-I.pif",
    "C7ODS-#-.*-#-I.pif",],
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",
    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        # create a new counter
        my $key_string = "";
        foreach (keys %$c_ref)
        {
            $key_string= $_;
            if ( $key_string eq "OBJ_ID" )
            {
                my $value_string = $c_ref->{$key_string};
                my(@obj_ids)=split(/\-/,$value_string);
                $c_ref->{'OPC_ID'}="$obj_ids[0]-$obj_ids[1]";
                $c_ref->{'DPC_ID'}="$obj_ids[0]-$obj_ids[2]";
                $c_ref->{'SIO_ID'}=$obj_ids[3];
                last;
            }
        }
        # keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'SO',

},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Split OBJ_ID into OPC_ID and SIO_ID for C7OD",
    'INPUT_FILE_DESCRIPTION' => [
    "C7OD-#-.*-#-I.pif",],
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",
    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        # create a new counter
        my $key_string = "";
        foreach (keys %$c_ref)
        {
            $key_string= $_;
            if ( $key_string eq "OBJ_ID" )
            {
                my $value_string = $c_ref->{$key_string};
                my(@obj_ids)=split(/\-/,$value_string);
                $c_ref->{'OPC_ID'}="$obj_ids[0]-$obj_ids[1]";
                $c_ref->{'DPC_ID'}="$obj_ids[0]-$obj_ids[2]";
                last;
            }
        }
        # keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'SO',

},


{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Replace space with underscore(SDIPHP, SDIPLP and SDIPMS) for OBJ_ID",
    'INPUT_FILE_DESCRIPTION' => ["SDIPHP-#-.*-#-I.pif",
    "SDIPLP-#-.*-#-I.pif",
    "SDIPMS-#-.*-#-I.pif"],
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",
    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        # create a new counter
        my $key_string = "";
        foreach (keys %$c_ref)
        {
            $key_string= $_;
            if ( $key_string eq "OBJ_ID" )
            {
                my $value_string = $c_ref->{$key_string};
                $value_string =~ s/\s+/_/g;
                $c_ref->{'OBJ_ID'}=$value_string;
                last;
            }
        }
        ## keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'RS',

},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Replace space with underscore (BSCQOS) for OBJ_ID and insert ",
    'INPUT_FILE_DESCRIPTION' => ["BSCQOS-#-.*-#-I.pif"],
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",
    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        # create a new counter
        my $key_string = "";
        foreach (keys %$c_ref)
        {
            $key_string= $_;
            if ( $key_string eq "OBJ_ID" )
            {
                my $value_string = $c_ref->{$key_string};
                $value_string =~ s/\s+/_/g;
                $c_ref->{'OBJ_ID'}=$value_string;
                $c_ref->{'QosTranslation'}=$value_string;
                last;
            }
        }
        ## keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'RSIC',

},


{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_NAME' => 'Accumulate NECELHOEX_EO',
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "NECELHOEX_EO",
    'INPUT_FILE_DESCRIPTION' => [ "NECELHOEX-#-.*-#-I-#-SO.pif"],
    'COUNTERS_TO_SORT_ON' => ["OBJ_ID_1"],
    'OLD_COUNTER_NAMES' => ["OBJ_ID_1"],
    'NEW_COUNTER_NAMES' => ["CELLID"],
    'NON_ADDITIVE_COUNTERS' => [],
    'REDUNDANT_COUNTERS' => ["OBJ_ID_1","OBJ_ID_2","OBJ_ID","OBJ_GROUP_NO","OBJ_TYPE_ID","NO_OBJ_RECORDS","NO_COUNTERS","OBJ_TYPE_FAULT_CODE"],
    'APPEND_STR' => "_EO",
},

{
    'RULE_TYPE' => 'JOIN',
    'RULE_NAME' => 'Join CLSDCCH, CLTCH',
    'INPUT_FILE_DESCRIPTION' => [ "CLSDCCH-#(.*)-#-\\d+-#-I.pif","CLTCH-#(.*)-#-\\d+-#-I.pif"],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "CLTCH",
    'COUNTERS_TO_JOIN_ON' => ['OBJ_ID'],
    'OUTPUT_FILENAME_START' => "CLTCH",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ["NODEID", "START_DATE", "START_TIME"],
    'NON_APPLICABLE_HEADER_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'REDUNDANT_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
},

{
    'RULE_TYPE' => 'JOIN',
    'RULE_NAME' => 'Join CELTCHF, CELTCHH',
    'INPUT_FILE_DESCRIPTION' => [ "CELTCHF-#(.*)-#-\\d+-#-I.pif","CELTCHH-#(.*)-#-\\d+-#-I.pif"],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "CELTCH",
    'COUNTERS_TO_JOIN_ON' => ['OBJ_ID'],
    'OUTPUT_FILENAME_START' => "CELTCH",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ["NODEID", "START_DATE", "START_TIME"],
    'NON_APPLICABLE_HEADER_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'REDUNDANT_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Insert constants to CELTCH block and remove line with all empty values",
    'INPUT_FILE_DESCRIPTION' => ["CELTCH-#-.*-#-J.pif"],
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",
    'HEADER_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        my $key="";
        foreach $key (keys(%insert_celtch_constants))
        {
            $c_ref->{$key}=$insert_celtch_constants{$key};
        }
        ## keep row
        return 0;
    },

    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        my $key="";
        my $counter_not_null_flag=0;
        foreach $key (keys(%$c_ref))
        {
            if ($$c_ref{$key} ne "" )
            {
                $counter_not_null_flag=1;
            }
        }
        if ($counter_not_null_flag==0)
        {
            return(1);
        }
        return(0);
    }
    ,
    'FILENAME_SUFFIX' => 'AC',

},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Extract APPLATFORM from OBJ_ID ",
    'INPUT_FILE_DESCRIPTION' => ["APDISKS-#-.*-#-I.pif"],
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",
    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        if ( $c_ref->{"OBJ_ID"} =~ /^(\w+\-\w+)\-\w+$/ )
        {
            $c_ref->{"APPLATFORM"}=$1;
        }
        ## keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'XAP',

},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Insert OBJ_ID from 8 to 15 based on row position",
    'INPUT_FILE_DESCRIPTION' => ["SS7HSLPG1-#-.*-#-I.pif",
                                 "SS7PRGRP-#-.*-#-I.pif",
                                 "SS7HSLPG2-#-.*-#-I.pif"],
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",
    'HEADER_COUNTERS_OP' => sub
    {

        $ss_seven_hslpg_cntr=8;

        ## keep row
        return 0;
    },
    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        $c_ref->{"OBJ_ID"} = $ss_seven_hslpg_cntr;

        $ss_seven_hslpg_cntr++;

        ## keep row
        return 0;
    },
    'FILENAME_SUFFIX' => 'IO',

},


{
    'RULE_TYPE' => 'JOIN',
    'RULE_NAME' => 'Join CLTCH, CELLCCHDR, CELTCHF, CELTCHH, RANDOMACC, CLSDCCH, CLSDCCHO, CLTCHDRF, CLTCHDRH, CLTCHDRAF, CLTCHDRAH',
    'INPUT_FILE_DESCRIPTION' => [ 
    "CLTCH-#(.*)-#-\\d+-#-I.pif",
    "CELLCCHDR-#(.*)-#-\\d+-#-I.pif",
    "CELTCHF-#(.*)-#-\\d+-#-I.pif",
    "CELTCHH-#(.*)-#-\\d+-#-I.pif", 
    "RANDOMACC-#(.*)-#-\\d+-#-I.pif", 
    "CLSDCCH-#(.*)-#-\\d+-#-I.pif", 
    "CLSDCCHO-#(.*)-#-\\d+-#-I.pif", 
    "CLTCHDRF-#(.*)-#-\\d+-#-I.pif", 
    "CLTCHDRH-#(.*)-#-\\d+-#-I.pif", 
    "CLTCHDRAF-#(.*)-#-\\d+-#-I.pif", 
    "CLTCHDRAH-#(.*)-#-\\d+-#-I.pif"],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "CELLTCH",
    'COUNTERS_TO_JOIN_ON' => ['OBJ_ID'],
    'OUTPUT_FILENAME_START' => "CELLTCH",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ["NODEID", "START_DATE", "START_TIME"],
    'NON_APPLICABLE_HEADER_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'REDUNDANT_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
},


{
    'RULE_TYPE' => 'JOIN',
    'RULE_NAME' => 'Join IDLEUTCHF, IDLEUTCHH, IDLEOTCHF, IDLEOTCHH',
    'INPUT_FILE_DESCRIPTION' => [ "IDLEUTCHF-#(.*)-#-\\d+-#-I.pif",
    "IDLEUTCHH-#(.*)-#-\\d+-#-I.pif",
    "IDLEOTCHF-#(.*)-#-\\d+-#-I.pif",
    "IDLEOTCHH-#(.*)-#-\\d+-#-I.pif"],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "IDLETCH",
    'COUNTERS_TO_JOIN_ON' => ['OBJ_ID'],
    'OUTPUT_FILENAME_START' => "IDLETCH",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ["NODEID", "START_DATE", "START_TIME"],
    'NON_APPLICABLE_HEADER_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'REDUNDANT_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
},

{
    'RULE_TYPE' => 'JOIN',
    'RULE_NAME' => 'Join CELLGPRS, CELLGPRS2, CELLGPRS3, CELLQOSG, CLDTMQOS',
    'INPUT_FILE_DESCRIPTION' => [ "CELLGPRS-#(.*)-#-\\d+-#-I.pif",
    "CELLGPRS2-#(.*)-#-\\d+-#-I.pif",
    "CELLGPRS3-#(.*)-#-\\d+-#-I.pif",
    "CELLQOSG-#(.*)-#-\\d+-#-I.pif",
    "CLDTMQOS-#(.*)-#-\\d+-#-I.pif"],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "CELLGPRSALL",
    'COUNTERS_TO_JOIN_ON' => ['OBJ_ID'],
    'OUTPUT_FILENAME_START' => "CELLGPRSALL",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ["NODEID", "START_DATE", "START_TIME"],
    'NON_APPLICABLE_HEADER_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'REDUNDANT_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
},

{
    'RULE_TYPE' => 'JOIN',
    'RULE_NAME' => 'Join C7SL1, C7SL2 and HS7SL1',
    'INPUT_FILE_DESCRIPTION' => [ "C7SL1-#(.*)-#-\\d+-#-I.pif",
    "C7SL2-#(.*)-#-\\d+-#-I.pif",
    "HS7SL1-#(.*)-#-\\d+-#-I.pif",],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "C7SL",
    'COUNTERS_TO_JOIN_ON' => ['OBJ_ID'],
    'OUTPUT_FILENAME_START' => "C7SL",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ["NODEID", "START_DATE", "START_TIME"],
    'NON_APPLICABLE_HEADER_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'REDUNDANT_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
},

{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_NAME' => 'Accumulate NCELLREL_O',
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "NCELLREL_O",
    'INPUT_FILE_DESCRIPTION' => ["NCELLREL-#-.*-#-I-#-SO.pif"],
    'COUNTERS_TO_SORT_ON' => ["OBJ_ID_1"],
    'OLD_COUNTER_NAMES' => ["OBJ_ID_1"],
    'NEW_COUNTER_NAMES' => ["CELLID"],
    'NON_ADDITIVE_COUNTERS' => [],
    'REDUNDANT_COUNTERS' => ["OBJ_ID_1","OBJ_ID_2","OBJ_ID","OBJ_GROUP_NO","OBJ_TYPE_ID","NO_OBJ_RECORDS","NO_COUNTERS","OBJ_TYPE_FAULT_CODE"],
    'APPEND_STR' => "_O",
},

{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_NAME' => 'Accumulate NCELLREL_I',
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "NCELLREL_I",
    'INPUT_FILE_DESCRIPTION' => [ "NCELLREL-#-.*-#-I-#-SO.pif"],
    'COUNTERS_TO_SORT_ON' => ["OBJ_ID_2"],
    'OLD_COUNTER_NAMES' => ["OBJ_ID_2"],
    'NEW_COUNTER_NAMES' => ["CELLID"],
    'NON_ADDITIVE_COUNTERS' => [],
    'REDUNDANT_COUNTERS' => ["OBJ_ID_1","OBJ_ID_2","OBJ_ID","OBJ_GROUP_NO","OBJ_TYPE_ID","NO_OBJ_RECORDS","NO_COUNTERS","OBJ_TYPE_FAULT_CODE"],
    'APPEND_STR' => "_I",
},

{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_NAME' => 'Accumulate NECELLREL_External_O',
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "NECELLREL_External_O",
    'INPUT_FILE_DESCRIPTION' => ["NECELLREL-#-.*-#-I-#-AX-#-SO.pif"],
    'COUNTERS_TO_SORT_ON' => ["OBJ_ID_1"],
    'OLD_COUNTER_NAMES' => ["OBJ_ID_1"],
    'NEW_COUNTER_NAMES' => ["CELLID"],
    'NON_ADDITIVE_COUNTERS' => [],
    'REDUNDANT_COUNTERS' => ["OBJ_ID_1","OBJ_ID_2","OBJ_ID","OBJ_GROUP_NO","OBJ_TYPE_ID","NO_OBJ_RECORDS","NO_COUNTERS","OBJ_TYPE_FAULT_CODE"],
    'APPEND_STR' => "_O",
},

{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_NAME' => 'ACCUM_CELEVENTI',
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "CELEVENTI",
    'INPUT_FILE_DESCRIPTION' => ["CELEVENTI-#-.*-#-I.pif"],
    'COUNTERS_TO_SORT_ON' => ["OBJ_ID"],
    'OLD_COUNTER_NAMES' => ["OBJ_ID"],
    'NEW_COUNTER_NAMES' => ["CELLID"],
    'NON_ADDITIVE_COUNTERS' => [],
    'REDUNDANT_COUNTERS' => ["OBJ_ID","OBJ_GROUP_NO","OBJ_TYPE_ID","NO_OBJ_RECORDS","NO_COUNTERS","OBJ_TYPE_FAULT_CODE"],
    'APPEND_STR' => "",
},

#{
#    'RULE_TYPE' => 'ACCUMULATE',
#    'RULE_NAME' => 'ACCUM_CELEVENTH',
#    'PRODUCE_PIF' => "True",
#    'PRODUCE_LIF' => 0,
#    'OUTPUT_BLOCK_NAME' => "CELEVENTH",
#    'INPUT_FILE_DESCRIPTION' => ["CELEVENTH-#-.*-#-I.pif"],
#    'COUNTERS_TO_SORT_ON' => ["OBJ_ID"],
#    'OLD_COUNTER_NAMES' => ["OBJ_ID"],
#    'NEW_COUNTER_NAMES' => ["CELLID"],
#    'NON_ADDITIVE_COUNTERS' => [],
#    'REDUNDANT_COUNTERS' => ["OBJ_ID","OBJ_GROUP_NO","OBJ_TYPE_ID","NO_OBJ_RECORDS","NO_COUNTERS","OBJ_TYPE_FAULT_CODE"],
#    'APPEND_STR' => "",
#},

{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_NAME' => 'ACCUM_CLRATECHG',
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "CLRATECHG",
    'INPUT_FILE_DESCRIPTION' => ["CLRATECHG-#-.*-#-I.pif"],
    'COUNTERS_TO_SORT_ON' => ["OBJ_ID"],
    'OLD_COUNTER_NAMES' => ["OBJ_ID"],
    'NEW_COUNTER_NAMES' => ["CELLID"],
    'NON_ADDITIVE_COUNTERS' => [],
    'REDUNDANT_COUNTERS' => ["OBJ_ID","OBJ_GROUP_NO","OBJ_TYPE_ID","NO_OBJ_RECORDS","NO_COUNTERS","OBJ_TYPE_FAULT_CODE"],
    'APPEND_STR' => "",
},


{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_NAME' => 'Accumulate NICELHO_O',
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "NICELHO_O",
    'INPUT_FILE_DESCRIPTION' => [ "NICELHO-#-.*-#-I-#-SO.pif"],
    'COUNTERS_TO_SORT_ON' => ["OBJ_ID_1"],
    'OLD_COUNTER_NAMES' => ["OBJ_ID_1"],
    'NEW_COUNTER_NAMES' => ["CELLID"],
    'NON_ADDITIVE_COUNTERS' => [],
    'REDUNDANT_COUNTERS' => ["OBJ_ID_1","OBJ_ID_2","OBJ_ID","OBJ_GROUP_NO","OBJ_TYPE_ID","NO_OBJ_RECORDS","NO_COUNTERS","OBJ_TYPE_FAULT_CODE"],
    'APPEND_STR' => "_O",
},

{
    'RULE_TYPE' => 'ACCUMULATE',
    'RULE_NAME' => 'Accumulate NICELHO_External_O',
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "NICELHO_External_O",
    'INPUT_FILE_DESCRIPTION' => [ "NICELHO-#-.*-#-I-#-AX-#-SO.pif"],
    'COUNTERS_TO_SORT_ON' => ["OBJ_ID_1"],
    'OLD_COUNTER_NAMES' => ["OBJ_ID_1"],
    'NEW_COUNTER_NAMES' => ["CELLID"],
    'NON_ADDITIVE_COUNTERS' => [],
    'REDUNDANT_COUNTERS' => ["OBJ_ID_1","OBJ_ID_2","OBJ_ID","OBJ_GROUP_NO","OBJ_TYPE_ID","NO_OBJ_RECORDS","NO_COUNTERS","OBJ_TYPE_FAULT_CODE"],
    'APPEND_STR' => "_O",
},

# Add                                                            
{                                                                
    'RULE_TYPE' => 'ACCUMULATE',                                     
    'RULE_NAME' => 'Accumulate NECELHO_O',                           
    'PRODUCE_PIF' => "True",                                         
    'PRODUCE_LIF' => 0,                                              
    'OUTPUT_BLOCK_NAME' => "NECELHO_O",                              
    'INPUT_FILE_DESCRIPTION' => [ "NECELHO-#-.*-#-I-#-AX-#-SO.pif"], 
    'COUNTERS_TO_SORT_ON' => ["OBJ_ID_1"],                           
    'OLD_COUNTER_NAMES' => ["OBJ_ID_1"],                             
    'NEW_COUNTER_NAMES' => ["CELLID"],                               
    'NON_ADDITIVE_COUNTERS' => [],                                   
    'REDUNDANT_COUNTERS' => ["OBJ_ID_1","OBJ_ID_2","OBJ_ID","OBJ_GROUP_NO","OBJ_TYPE_ID","NO_OBJ_RECORDS","NO_COUNTERS","OBJ_TYPE_FAULT_CODE"],              
    'APPEND_STR' => "_O",                                            
},                                               

{
    'RULE_TYPE' => 'JOIN',
    'RULE_NAME' => 'JOIN CELLHO',
    'INPUT_FILE_DESCRIPTION' => [
    "NCELLREL-#(.*)-#-\\d+-#-I-#-SO-#-NCELLREL_I-#-A.pif",
    "NCELLREL-#(.*)-#-\\d+-#-I-#-SO-#-NCELLREL_O-#-A.pif",
    "NECELLREL-#(.*)-#-\\d+-#-I-#-AX-#-SO-#-NECELLREL_External_O-#-A.pif",
    "CELEVENTI-#(.*)-#-\\d+-#-I-#-CELEVENTI-#-A.pif",
    #"CELEVENTH-#(.*)-#-\\d+-#-I-#-CELEVENTH-#-A.pif",
    "CLRATECHG-#(.*)-#-\\d+-#-I-#-CLRATECHG-#-A.pif", 
    "NICELHO-#(.*)-#-\\d+-#-I-#-SO-#-NICELHO_O-#-A.pif",
    #"NECELHO-#(.*)-#-\\d+-#-I-#-AX-#-SO-#-NECELHO_External_O-#-A.pif"],                                                         
    "NECELHO-#(.*)-#-\\d+-#-I-#-AX-#-SO-#-NECELHO_O-#-A.pif"],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "CELLHO",
    'COUNTERS_TO_JOIN_ON' => ['CELLID'],
    'OUTPUT_FILENAME_START' => "CELLHO",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ["NODEID", "START_DATE", "START_TIME"],
    'NON_APPLICABLE_HEADER_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'REDUNDANT_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
},

#JOIN CLTCH, CLSDCCH, CELLGPRS, CELLGPRS2, CLSMS, CELTCHF, CELTCHH
# ------------------------------------------------------
{
    'RULE_TYPE' => 'JOIN',
    'RULE_NAME' => 'Intermediate CELLGROUP block construction',
    'INPUT_FILE_DESCRIPTION'   => ["CLTCH-#-(.*)-#-\\d+-#-I.pif",
    "CLSDCCH-#-(.*)-#-\\d+-#-I.pif",
    "CELLGPRS-#-(.*)-#-\\d+-#-I.pif",
    "CELLGPRS2-#-(.*)-#-\\d+-#-I.pif",
    "CLSMS-#-(.*)-#-\\d+-#-I.pif",
    "CELTCHF-#-(.*)-#-\\d+-#-I.pif",
    "CELTCHH-#-(.*)-#-\\d+-#-I.pif"],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,
    'OUTPUT_BLOCK_NAME' => "CELLGROUP",
    'COUNTERS_TO_JOIN_ON' => ['OBJ_ID'],
    'OUTPUT_FILENAME_START' => "CELLGROUP",
    'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ["NODEID", "START_DATE", "START_TIME"],
    'NON_APPLICABLE_HEADER_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'REDUNDANT_COUNTERS' => ["OBJ_TYPE_ID","FILLER", "NO_COUNTERS", "NO_OBJ_RECORDS"],
    'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
},

{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Remove lines that contains ALL empty counters",
    'INPUT_FILE_DESCRIPTION' => [ "CELLGROUP-#-.*-#-J.pif"  ],
    'PRODUCE_PIF' => "True",
    'PRODUCE_LIF' => 0,

    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        my $key="";
        my $counter_not_null_flag=0;
        foreach $key (keys(%$c_ref))
        {
            if ($$c_ref{$key} ne "" )
            {
                $counter_not_null_flag=1;
            }
        }
        if ($counter_not_null_flag==0)
        {
            return(1);
        }
        return(0);
    },
    'FILENAME_SUFFIX' => 'RL',

},
# To accumulate to get the Group KPI
# ----------------------------------
{
    'RULE_TYPE'                => 'ACCUMULATE',
    'RULE_DESC'                => 'Accumulate for to group KPI',
    'INPUT_FILE_DESCRIPTION'   => ["CELLGROUP-#-.*-#-RL.pif"],
    'PRODUCE_PIF'              => 0,
    'PRODUCE_LIF'              => "True",
    #'APPEND_STR'               => '_groupkpi',
    #'OUTPUT_FORMAT'            => 'LIF_Writer',
    'OUTPUT_BLOCK_NAME'        => "CELLGROUP",
    'COUNTERS_TO_SORT_ON'      => [],
    'NON_ADDITIVE_COUNTERS' => ["OBJ_ID"],
    'REDUNDANT_COUNTERS'       => ["OBJ_TYPE_ID","FILLER","NO_COUNTERS","NO_OBJ_RECORDS","OBJ_ID"],
},


{
    'RULE_TYPE' => 'PERLIZE',
    'RULE_NAME' => "Remove lines that contains ALL empty counters",
    'INPUT_FILE_DESCRIPTION' => [    "CLTCH-#-.*-#-J.pif",
    "CELLTCH-#-.*-#-J.pif",
    "IDLETCH-#-.*-#-J.pif",
    "CELLGPRSALL-#-.*-#-J.pif",
    "CELLHO-#-.*-#-J.pif", ],
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",

    'DATA_COUNTERS_OP' => sub
    {
        my $c_ref = shift;
        my $key="";
        my $counter_not_null_flag=0;
        foreach $key (keys(%$c_ref))
        {
            if ($$c_ref{$key} ne "" )
            {
                $counter_not_null_flag=1;
            }
        }
        if ($counter_not_null_flag==0)
        {
            return(1);
        }
        return(0);
    },
    'FILENAME_SUFFIX' => 'RL',

},
#-------------------------------------------------------------------------------
{'RULE_TYPE' => 'PIF_2_LIF',
    'RULE_NAME' => "Ericsson 6.0 PIF to LIF",
    'INPUT_FILE_DESCRIPTION' => ["ABISIP-#-.*-#-I.pif",
    "NEIGHBOURHO-#-.*-#-J-#-SO.pif",
    "NONRES64K-#-.*-#-I.pif",
    "RES64K-#-.*-#-I.pif",
    "SUPERCH-#-.*-#-I.pif",
    "CELLMSCAP-#-.*-#-I.pif",
    "LOADREG-#-.*-#-I.pif",
    "CELEVENT1-#-.*-#-I.pif",
    "CELLMSQ-#-.*-#-I.pif",
    "CLTCHDRF-#-.*-#-I.pif",
    "CLTCHDRAH-#-.*-#-I.pif",
    "PREEMP-#-.*-#-I.pif",
    #"CELLGPRS-#-.*-#-I.pif",
    "CELLGPRS2-#-.*-#-I.pif",
    "CELLGPRS3-#-.*-#-I.pif",
    "CELLGPRS4-#-.*-#-I.pif",
    "CELLGPRSO-#-.*-#-I.pif",
    "CLDTMPER-#-.*-#-I.pif",
    "TRAFDLGPRS-#-.*-#-I.pif",
    "CLTCHDRAF-#-.*-#-I.pif",
    "DIP-#-.*-#-I.pif",
    "C7SIO-#-.*-#-I.pif",
    "C7SL-#-.*-#-J.pif",
    "C7SL1-#-.*-#-I.pif",
    "C7SL2-#-.*-#-I.pif",
    #"C7LSSI-#-.*-#-I.pif",
    #"C7DPCSIO-#-.*-#-I.pif",
    "C7OD-#-.*-#-I.pif",
    #"C7OPCDS-#-.*-#-I.pif",
    #"C7OPCSIO-#-.*-#-I.pif",
    "C7RTSET-#-.*-#-I.pif",
    "C7SCSUBSYS-#-.*-#-I.pif",
    "C7SCSIGP-#-.*-#-I.pif",
    "C7SLSET-#-.*-#-I.pif",
    "HS7SL1-#-.*-#-I.pif",
    "SS7SLMT1-#-.*-#-I.pif",
    "SS7SLMT2-#-.*-#-I.pif",
    "SS7LS-#-.*-#-I.pif",
    "SS7SLTRAFF-#-.*-#-I.pif",
    "SS7SCSUBSY-#-.*-#-I.pif",
    "SS7TT-#-.*-#-I.pif",
    #"SS7PRGRP-#-.*-#-I.pif",
    #"SS7HSLPG2-#-.*-#-I.pif",
    #"SDIPMS-#-.*-#-I.pif",
    #"SDIPHP-#-.*-#-I.pif",
    #"SDIPLP-#-.*-#-I.pif",
    "GRPSWITCH-#-.*-#-I.pif",
    "SNT-#-.*-#-I.pif",
    "DIGS-#-.*-#-I.pif",
    "DIGPATH-#-.*-#-I.pif",
    "NETWSYNC-#-.*-#-I.pif",
    #"APDISKS-#-.*-#-I.pif",
    "SPHD-#-.*-#-I.pif",
    "APPLATFORM-#-.*-#-I.pif",
    "SS7SCCPUSE-#-.*-#-I.pif",
    "SS7SCQOS-#-.*-#-I.pif",
    "C7SCCPUSE-#-.*-#-I.pif",
    "C7SCPERF-#-.*-#-I.pif",
    "C7SCQOS-#-.*-#-I.pif",
    "ATERTRANS-#-.*-#-I.pif",
    "BSC-#-.*-#-I.pif",
    "BSCGPRS-#-.*-#-I.pif",
    "BSCGPRS2-#-.*-#-I.pif",
    "BSCMSLOT-#-.*-#-I.pif",
    "BSCPOS-#-.*-#-I.pif",
    #"BSCQOS-#-.*-#-I.pif",
    "GPHLOADREG-#-.*-#-I.pif",
    "DELSTRTBF-#-.*-#-I.pif",
    "LOAS-#-.*-#-I.pif",
    "LOADREG-#-.*-#-I.pif",
    "LOASMISC-#-.*-#-I.pif",
    "TRALOST-#-.*-#-I.pif",
    "MSC-#-.*-#-I.pif",
    "CP-#-.*-#-I.pif",
    "EMGPRS-#-.*-#-I.pif",
    "EMSTAT-#-.*-#-I.pif",
    "LAPD-#-.*-#-I.pif",
    "TRAPCOM-#-.*-#-I.pif",
    "TRASEVENT-#-.*-#-I.pif",
    "TRAPEVENT-#-.*-#-I.pif",
    "MOTG-#-.*-#-I.pif",
    "MOTS-#-.*-#-I.pif",
    "DOWNTIME-#-.*-#-I.pif",
    "CCCHLOAD-#-.*-#-I.pif",
    "CELEVENTD-#-.*-#-I.pif",
    "CELEVENTH-#-.*-#-I.pif",
    "CELEVENTI-#-.*-#-I.pif",
    "CELEVENTSC-#-.*-#-I.pif",
    "CELLAFFER-#-.*-#-I.pif",
    "CELLAHFER-#-.*-#-I.pif",
    "CELLCONF-#-.*-#-I.pif",
    "CELLDUALT-#-.*-#-I.pif",
    "CELLEFFER-#-.*-#-I.pif",
    "CELLFERF-#-.*-#-I.pif",
    "CELLFERH-#-.*-#-I.pif",
    "CELLFFER-#-.*-#-I.pif",
    "CELLFLXAB-#-.*-#-I.pif",
    "CELLGPRSO-#-.*-#-I.pif",
    "CELLHFER-#-.*-#-I.pif",
    "CELLQOSEG-#-.*-#-I.pif",
    "CELLQOSS-#-.*-#-I.pif",
    "CELLSQI-#-.*-#-I.pif",
    "CELLPOS-#-.*-#-I.pif",
    "CELLSQIDL-#-.*-#-I.pif",
    "CLDTMEST-#-.*-#-I.pif",
    "CLDTMPER-#-.*-#-I.pif",
    "CLDTMQOS-#-.*-#-I.pif",
    "CLRATECHG-#-.*-#-I.pif",
    "CLRXQUAL-#-.*-#-I.pif",
    "CELLCCHDR-#-.*-#-I.pif",
    "CELLCCHHO-#-.*-#-I.pif",
    "CLSDCCH-#-.*-#-I.pif",
    "CLSDCCHO-#-.*-#-I.pif",
    "CLSMS-#-.*-#-I.pif",
    #"CLTCH-#-.*-#-I.pif",
    "CLTCHDRH-#-.*-#-I.pif",
    "RANDOMACC-#-.*-#-I.pif",
    "RNDACCEXT-#-.*-#-I.pif",
    "CELLHCS-#-.*-#-I.pif",
    "CELEVENTS-#-.*-#-I.pif",
    "CELLPAG-#-.*-#-I.pif",
    "CLTCHFV3C-#-.*-#-I.pif",
    "IDLEOTCHF-#-.*-#-I.pif",
    "IDLEUTCHF-#-.*-#-I.pif",
    "IDLEOTCHH-#-.*-#-I.pif",
    "IDLEUTCHH-#-.*-#-I.pif",
    "CCCHLOAD-#-.*-#-I.pif",
    "CELLEIT-#-.*-#-I.pif",
    "CELLEIT2-#-.*-#-I.pif",
    #"CELLGPRS-#-.*-#-I.pif",
    "CELLGPRS2-#-.*-#-I.pif",
    "CELLGPRS3-#-.*-#-I.pif",
    #"CELTCH-#-.*-#-J-#-AC.pif",
    "CELLGPRS4-#-.*-#-I.pif",
    "CELLQOSG-#-.*-#-I.pif",
    "TRAFDLGPRS-#-.*-#-I.pif",
    "TRAFULGPRS-#-.*-#-I.pif",
    "CELTCHFP-#-.*-#-I.pif",
    "NUCELLREL-#-.*-#-I-#-SO.pif",
    "CELLHSCSD-#-.*-#-I.pif",
    "PREEMP-#-.*-#-I.pif",
    "CELLMSQ-#-.*-#-I.pif",
    "CLQOSSCON-#-.*-#-I.pif",
    "CLQOSSCON2-#-.*-#-I.pif",
    "CHGRP0SQI-#-.*-#-I.pif",
    "CHGRP0F-#-.*-#-I.pif",
    "CHGRP0H-#-.*-#-I.pif",
    "CLTCHDRH-#-.*-#-I.pif",
    "CLTCHDRAF-#-.*-#-I.pif",
    "CLTCHDRF-#-.*-#-I.pif",
    "CLTCHDRAH-#-.*-#-I.pif",
    "CLTCHFV1-#-.*-#-I.pif",
    "CLTCHFV2-#-.*-#-I.pif",
    "CLTCHHV1-#-.*-#-I.pif",
    "CLTCHHV2-#-.*-#-I.pif",
    "CLTCHHV3-#-.*-#-I.pif",
    "CLTCHFV3-#-.*-#-I.pif",
    "CLTCHHV3C-#-.*-#-I.pif",
    "CLVGCSEST-#-.*-#-I.pif",
    "RLINKBITR-#-.*-#-I.pif",
    "TRAFGPRS2-#-.*-#-I.pif",
    "TRAFGPRS3-#-.*-#-I.pif",
    "NCELLREL-#-.*-#-I-#-SO.pif",
    "NECELASS-#-.*-#-I-#-SO.pif",
    #"NECELHO-#-.*-#-I-#-AX-#-SO.pif",
    "NECELHO-#-.*-#-I-#-SO.pif",
    "NECELHOEX-#-.*-#-I-#-SO.pif",
    #"NECELLREL-#-.*-#-I-#-AX-#-SO.pif",
    "NECELLREL-#-.*-#-I-#-SO.pif",
    "NICELASS-#-.*-#-I-#-SO.pif",
    "NICELHO-#-.*-#-I-#-SO.pif",
    "NICELHOEX-#-.*-#-I-#-SO.pif",
    "EMGSTAT-#-.*-#-I.pif",
    "SPDL-#-.*-#-I.pif",
    "TRASUBPOOL-#-.*-#-I.pif",
    #### NEW ####
    "PGW-#-.*-#-I.pif",
    "PGWLDIST-#-.*-#-I.pif",
    "SUPERCH2-#-.*-#-I.pif",
    "TRH-#-.*-#-I.pif",
    "SS7TOTAL-#-.*-#-I.pif",
    "SS7TOTAL2-#-.*-#-I.pif",
    "SS7TIMERS-#-.*-#-I.pif",
    "TCABO-#-.*-#-I.pif",
    "TCREJ-#-.*-#-I.pif",
    "TCUSE-#-.*-#-I.pif",
    "TPLAT-#-.*-#-I.pif",
    "TCCMP-#-.*-#-I.pif",
    "TCDIA-#-.*-#-I.pif",
    "TCMSG-#-.*-#-I.pif",
    "C7RTTOTAL-#-.*-#-I.pif",
    "GANDIREPA-#-.*-#-I.pif",
    "GANRESALL-#-.*-#-I.pif",
    "GANRPLOAD-#-.*-#-I.pif",
    "EMG-#-.*-#-I.pif",
    "EM-#-.*-#-I.pif",
    "EMRP-#-.*-#-I.pif",
    "CVTR02-#-.*-#-I.pif",
    "MRVFAIL-#-.*-#-I.pif",
    "SCTPAM-#-.*-#-I.pif",
    "SCTPLM-#-.*-#-I.pif",
    "SS7HSLS-#-.*-#-I.pif",
    "SS7HSLTRAF-#-.*-#-I.pif",
    "SS7HSLMT1-#-.*-#-I.pif",
    "SS7HSLMT2-#-.*-#-I.pif",
    "SS7HSLMT3-#-.*-#-I.pif",
    "RP-#-.*-#-I.pif",
    "SPSP-#-.*-#-I.pif",    
    "SS7GWON-#-.*-#-I.pif",    
    "SS7GWONTT-#-.*-#-I.pif",    
    ] ,
    'PRODUCE_PIF' => 0,
    'PRODUCE_LIF' => "True",
},
);  

#-------------------------------------------------------------------------------

sub postparser_config {
    return \@rules;
}

1;
